==> db4o-5.0-mono.tar.gz: db4o-5.0/src/core/src/core/com/db4o/inside/ix/NIxPath.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
namespace com.db4o.inside.ix
{
	/// <exclude></exclude>
	public class NIxPath : com.db4o.Tree
	{
		internal readonly com.db4o.inside.ix.NIxPathNode _head;

		internal readonly bool _takePreceding;

		internal readonly bool _takeMatches;

		internal readonly bool _takeSubsequent;

		internal int _type;

		public NIxPath(com.db4o.inside.ix.NIxPathNode head, bool takePreceding, bool takeMatches
			, bool takeSubsequent, int pathType)
		{
			_head = head;
			_takePreceding = takePreceding;
			_takeMatches = takeMatches;
			_takeSubsequent = takeSubsequent;
			_type = pathType;
		}

		public override int compare(com.db4o.Tree a_to)
		{
			com.db4o.inside.ix.NIxPath other = (com.db4o.inside.ix.NIxPath)a_to;
			return _head.compare(other._head, _type, other._type);
		}

		public override string ToString()
		{
			string str = "NIxPath +\n";
			string space = " ";
			com.db4o.inside.ix.NIxPathNode node = _head;
			while (node != null)
			{
				str += space;
				space += " ";
				str += node.ToString() + "\n";
				node = node._next;
			}
			return str;
		}
	}
}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/core/src/core/com/db4o/inside/ix/NIxPath.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
namespace com.db4o.inside.ix
{
	/// <exclude></exclude>
	public class NIxPath : com.db4o.Tree
	{
		internal readonly com.db4o.inside.ix.NIxPathNode _head;

		internal readonly bool _takePreceding;

		internal readonly bool _takeMatches;

		internal readonly bool _takeSubsequent;

		internal int _type;

		public NIxPath(com.db4o.inside.ix.NIxPathNode head, bool takePreceding, bool takeMatches
			, bool takeSubsequent, int pathType)
		{
			_head = head;
			_takePreceding = takePreceding;
			_takeMatches = takeMatches;
			_takeSubsequent = takeSubsequent;
			_type = pathType;
		}

		public override int Compare(com.db4o.Tree a_to)
		{
			com.db4o.inside.ix.NIxPath other = (com.db4o.inside.ix.NIxPath)a_to;
			return _head.Compare(other._head, _type, other._type);
		}

		public override string ToString()
		{
			return base.ToString();
			string str = "NIxPath +\n";
			string space = " ";
			com.db4o.inside.ix.NIxPathNode node = _head;
			while (node != null)
			{
				str += space;
				space += " ";
				str += node.ToString() + "\n";
				node = node._next;
			}
			return str;
		}

		public override object ShallowClone()
		{
			com.db4o.inside.ix.NIxPath path = new com.db4o.inside.ix.NIxPath(_head, _takePreceding
				, _takeMatches, _takeSubsequent, _type);
			base.ShallowCloneInternal(path);
			return path;
		}
	}
}
